.. include:: ../README.rst

This documentation
------------------

.. toctree::
   :maxdepth: 2
  
   overview
   license
   todo

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
